@@ -1,7 +1,7 @@
 /* Closures for Bison
 
-   Copyright (C) 1984, 1989, 2000-2002, 2004-2005, 2007, 2009-2015 Free
-   Software Foundation, Inc.
+   Copyright (C) 1984, 1989, 2000-2002, 2004-2005, 2007, 2009-2015, 2018
+   Free Software Foundation, Inc.
 
    This file is part of Bison, the GNU Compiler Compiler.
 
